summaryrefslogtreecommitdiff
path: root/jstests/replsets/refresh_sessions_rs.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/replsets/refresh_sessions_rs.js')
-rw-r--r--jstests/replsets/refresh_sessions_rs.js5
1 files changed, 3 insertions, 2 deletions
diff --git a/jstests/replsets/refresh_sessions_rs.js b/jstests/replsets/refresh_sessions_rs.js
index 9bd4527c7bf..3a5cdd98218 100644
--- a/jstests/replsets/refresh_sessions_rs.js
+++ b/jstests/replsets/refresh_sessions_rs.js
@@ -51,8 +51,9 @@
res = db2.runCommand(refresh);
assert.commandWorked(res, "failed to refresh");
- // Connect to the primary. The sessions collection here should not yet contain records.
- assert.eq(db1.system.sessions.count(), 0, "flushed refresh to the primary prematurely");
+ // Connect to the primary. The sessions collection here should have one record for the session
+ // on the secondary.
+ assert.eq(db1.system.sessions.count(), 1, "failed to refresh on the secondary");
// Trigger a refresh on the primary. The sessions collection should now contain two records.
res = db1.runCommand(refresh);